diff src/misc1.c @ 2672:6a2e4860134b v7.3.091

updated for version 7.3.091 Problem: "vim -w foo" writes special key codes for removed escape sequences. (Josh Triplett) Solution: Don't write K_IGNORE codes.
author Bram Moolenaar <bram@vim.org>
date Thu, 30 Dec 2010 12:30:31 +0100
parents b2a7d143abe2
children 862d920800b1
line wrap: on
line diff
--- a/src/misc1.c
+++ b/src/misc1.c
@@ -3114,10 +3114,11 @@ get_keystroke()
 	       && (!p_ttimeout || waited * 100L < (p_ttm < 0 ? p_tm : p_ttm)))
 	    continue;
 
-	/* found a termcode: adjust length */
-	if (n > 0)
+	if (n == KEYLEN_REMOVED)  /* key code removed */
+	    continue;
+	if (n > 0)		/* found a termcode: adjust length */
 	    len = n;
-	if (len == 0)	    /* nothing typed yet */
+	if (len == 0)		/* nothing typed yet */
 	    continue;
 
 	/* Handle modifier and/or special key code. */